@@ -4,16 +4,16 @@ import numpy as np
 def res_to_chi2(res: np.ndarray):
     """
     We assume that the residuals res are related to an objective function
-    value fval = chi2 via::
+    value chi2 via::
 
-        fval = 0.5 * sum(res**2)
-
-    which is the 'Linear' formulation in scipy.
+        chi2 = sum(res**2)
 
+    which is consistent with the AMICI definition but NOT the 'Linear'
+    formulation in scipy.
     """
     if res is None:
         return None
-    return 0.5 * np.power(res, 2).sum()
+    return np.dot(res, res)
 
 
 def sres_to_schi2(res: np.ndarray, sres: np.ndarray):
@@ -22,7 +22,7 @@ def sres_to_schi2(res: np.ndarray, sres: np.ndarray):
     """
     if res is None or sres is None:
         return None
-    return res.dot(sres)
+    return 2 * res.dot(sres)
 
 
 def sres_to_fim(sres: np.ndarray):
