@@ -13,4 +13,4 @@ from .parallel_tempering import ParallelTemperingSampler
 from .adaptive_parallel_tempering import AdaptiveParallelTemperingSampler
 from .pymc3 import Pymc3Sampler
 from .result import McmcPtResult
-from .diagnostics import geweke_test
+from .diagnostics import geweke_test, auto_correlation, effective_sample_size
