@@ -2,7 +2,6 @@
 This is for testing optimization of the pypesto.Objective.
 """
 
-
 import numpy as np
 import pytest
 import test.test_objective as test_objective
@@ -26,8 +25,9 @@ optimizers = [
         'ls_trf', 'ls_dogbox']],
     # disabled: ,'trust-constr', 'ls_lm', 'dogleg'
     ('ipopt', ''),
-    ('dlib', 'default'),
+    ('dlib', ''),
     ('pyswarm', ''),
+    ('cmaes', ''),
 ]
 
 
@@ -60,7 +60,6 @@ def test_optimization(mode, optimizer):
 
 
 def check_minimize(objective, library, solver, allow_failed_starts=False):
-
     options = {
         'maxiter': 100
     }
@@ -72,9 +71,11 @@ def check_minimize(objective, library, solver, allow_failed_starts=False):
     elif library == 'ipopt':
         optimizer = optimize.IpoptOptimizer()
     elif library == 'dlib':
-        optimizer = optimize.DlibOptimizer(method=solver, options=options)
+        optimizer = optimize.DlibOptimizer(options=options)
     elif library == 'pyswarm':
         optimizer = optimize.PyswarmOptimizer(options=options)
+    elif library == 'cmaes':
+        optimizer = optimize.CmaesOptimizer(options=options)
 
     lb = 0 * np.ones((1, 2))
     ub = 1 * np.ones((1, 2))
