@@ -3,6 +3,7 @@ This is for testing the fixing of parameters feature.
 """
 import numpy as np
 import pypesto
+import pypesto.optimize
 from .test_objective import rosen_for_sensi
 
 
@@ -17,9 +18,9 @@ def test_problem():
 
 def test_optimize():
     problem = create_problem()
-    optimizer = pypesto.ScipyOptimizer()
+    optimizer = pypesto.optimize.ScipyOptimizer()
     n_starts = 5
-    result = pypesto.minimize(problem, optimizer, n_starts)
+    result = pypesto.optimize.minimize(problem, optimizer, n_starts)
 
     optimizer_result = result.optimize_result.list[0]
     assert len(optimizer_result.x) == 5
